端口_HTTP = 80
端口_HTTPS = 443
端口_FTP = 21
端口_FTPS = 990
端口_SSH = 22
端口_TELNET = 23
端口_SMTP = 25
端口_DNS = 53
端口_DHCP_服务器 = 67
端口_DHCP_客户端 = 68
端口_POP3 = 110
端口_NTP = 123
端口_IMAP = 143
端口_SNMP = 161
端口_BGP = 179
端口_LDAP = 389
端口_HTTPS备用 = 8443
端口_SMTPS = 465
端口_Submission = 587
端口_IMAPS = 993
端口_POP3S = 995
端口_MySQL = 3306
端口_PostgreSQL = 5432
端口_Redis = 6379
端口_MongoDB = 27017
端口_SQLServer = 1433

协议_HTTP = "http"
协议_HTTPS = "https"
协议_FTP = "ftp"
协议_SFTP = "sftp"
协议_WS = "ws"
协议_WSS = "wss"
协议_SMTP = "smtp"
协议_POP3 = "pop3"
协议_IMAP = "imap"

本地主机_IP = "127.0.0.1"
本地主机域名 = "localhost"
广播地址 = "255.255.255.255"

状态_成功下限 = 200
状态_成功上限 = 299
状态_重定向下限 = 300
状态_重定向上限 = 399
状态_客户端错误下限 = 400
状态_客户端错误上限 = 499
状态_服务端错误下限 = 500
状态_服务端错误上限 = 599
