import psutil


def PID_终止进程(pid: int | str) -> bool:
    """
    根据进程 PID 终止指定进程。

    功能说明：
        - 会先调用 terminate()，再等待进程退出。
        - 当 PID 不存在、无权限访问、参数无效或发生异常时，返回 False。

    Args:
        pid (int | str): 要终止的进程 PID。

    Returns:
        bool: 终止成功返回 True；失败返回 False。
    """
    try:
        pid = int(pid)
        进程对象 = psutil.Process(pid)
        进程对象.terminate()
        try:
            进程对象.wait(timeout=3)
        except psutil.TimeoutExpired:
            return False
        return True
    except Exception:
        return False
