import psutil


def PID_取内存占用(pid: int | str) -> int:
    """
    根据进程 PID 获取当前内存占用大小，单位为字节。

    功能说明：
        - 返回值为进程当前 RSS 内存占用。
        - 参数无效、进程不存在、无权限访问或发生异常时返回 0。

    Args:
        pid (int | str): 要查询的进程 PID。

    Returns:
        int: 成功返回内存占用字节数；失败返回 0。
    """
    try:
        pid = int(pid)
        return int(psutil.Process(pid).memory_info().rss)
    except Exception:
        return 0
