继续 = 100  # 继续
切换协议 = 101  # 切换协议
处理 = 102  # 处理
早期提示 = 103  # Early Hints
支持上传续传 = 104  # Upload Resumption Supported（IANA 临时登记状态码）
请求成功 = 200  # 请求成功
已创建 = 201  # 已创建
已接受 = 202  # 已接受
非授权信息 = 203  # 非授权信息
无内容 = 204  # 无内容
重置内容 = 205  # 重置内容
部分内容 = 206  # 部分内容
多状态 = 207  # 多状态
已报告 = 208  # 已报告
IM使用 = 226  # IM使用
多种选择 = 300  # 多种选择
永久移动 = 301  # 永久移动
已找到 = 302  # Found
查看其他位置 = 303  # 查看其他位置
未修改 = 304  # 未修改
使用代理 = 305  # 使用代理
未使用 = 306  # Unused
临时重定向 = 307  # 临时重定向
永久重定向 = 308  # 永久重定向
错误请求 = 400  # 错误请求
未授权 = 401  # 未授权
支付要求 = 402  # 支付要求
禁止 = 403  # 禁止
未找到 = 404  # 未找到
方法禁用 = 405  # 方法禁用
不接受 = 406  # 不接受
需要代理授权 = 407  # 需要代理授权
请求超时 = 408  # 请求超时
冲突 = 409  # 冲突
已删除 = 410  # 已删除
需要有效长度 = 411  # 需要有效长度
未满足前提条件 = 412  # 未满足前提条件
内容过大 = 413  # Content Too Large
URI过长 = 414  # URI Too Long
不支持的媒体类型 = 415  # 不支持的媒体类型
请求范围不符合要求 = 416  # 请求范围不符合要求
期望失败 = 417  # 期望失败
未使用_418 = 418  # Unused
请求被错误路由 = 421  # Misdirected Request
无法处理的内容 = 422  # Unprocessable Content
锁定 = 423  # 锁定
失败依赖 = 424  # 失败依赖
为时过早 = 425  # Too Early
未升级 = 426  # 未升级
需要前提条件 = 428  # Precondition Required
请求过多 = 429  # Too Many Requests
请求头字段过大 = 431  # Request Header Fields Too Large
因法律原因不可用 = 451  # Unavailable For Legal Reasons
服务器内部错误 = 500  # 服务器内部错误
尚未实施 = 501  # 尚未实施
错误网关 = 502  # 错误网关
服务不可用 = 503  # 服务不可用
网关超时 = 504  # 网关超时
HTTP版本不受支持 = 505  # HTTP版本不受支持
变体也可协商 = 506  # 变体也可协商
存储不足 = 507  # 存储不足
循环引用 = 508  # 循环引用
未扩展 = 510  # Not Extended（已废弃）
网络身份验证要求 = 511  # 网络身份验证要求
