import psutil


def PID_是否存在(pid: int | str) -> bool:
    """
    判断指定 PID 对应的进程是否存在。

    功能说明：
        - 当 PID 对应的进程存在时返回 True。
        - 参数无效、进程不存在或发生异常时返回 False。

    Args:
        pid (int | str): 要判断的进程 PID。

    Returns:
        bool: 进程存在返回 True；否则返回 False。
    """
    try:
        pid = int(pid)
        return psutil.pid_exists(pid)
    except Exception:
        return False
