安道尔 = "AD"  # 安道尔
阿拉伯联合酋长国 = "AE"  # 阿拉伯联合酋长国
阿富汗 = "AF"  # 阿富汗
安提瓜和巴布达 = "AG"  # 安提瓜和巴布达
安圭拉 = "AI"  # 安圭拉
阿尔巴尼亚 = "AL"  # 阿尔巴尼亚
亚美尼亚 = "AM"  # 亚美尼亚
安哥拉 = "AO"  # 安哥拉
南极洲 = "AQ"  # 南极洲
阿根廷 = "AR"  # 阿根廷
美属萨摩亚 = "AS"  # 美属萨摩亚
奥地利 = "AT"  # 奥地利
澳大利亚 = "AU"  # 澳大利亚
阿鲁巴 = "AW"  # 阿鲁巴
奥兰群岛 = "AX"  # 奥兰群岛
阿塞拜疆 = "AZ"  # 阿塞拜疆
波斯尼亚和黑塞哥维那 = "BA"  # 波斯尼亚和黑塞哥维那
巴巴多斯 = "BB"  # 巴巴多斯
孟加拉国 = "BD"  # 孟加拉国
比利时 = "BE"  # 比利时
布基纳法索 = "BF"  # 布基纳法索
保加利亚 = "BG"  # 保加利亚
巴林 = "BH"  # 巴林
布隆迪 = "BI"  # 布隆迪
贝宁 = "BJ"  # 贝宁
圣巴泰勒米 = "BL"  # 圣巴泰勒米
百慕大 = "BM"  # 百慕大
文莱 = "BN"  # 文莱
玻利维亚 = "BO"  # 玻利维亚
巴西 = "BR"  # 巴西
巴哈马 = "BS"  # 巴哈马
不丹 = "BT"  # 不丹
布韦岛 = "BV"  # 布韦岛
博茨瓦纳 = "BW"  # 博茨瓦纳
白俄罗斯 = "BY"  # 白俄罗斯
伯利兹 = "BZ"  # 伯利兹
加拿大 = "CA"  # 加拿大
刚果民主共和国 = "CD"  # 刚果民主共和国
中非共和国 = "CF"  # 中非共和国
刚果共和国 = "CG"  # 刚果共和国
瑞士 = "CH"  # 瑞士
科特迪瓦 = "CI"  # 科特迪瓦
库克群岛 = "CK"  # 库克群岛
智利 = "CL"  # 智利
喀麦隆 = "CM"  # 喀麦隆
中国 = "CN"  # 中国
哥伦比亚 = "CO"  # 哥伦比亚
哥斯达黎加 = "CR"  # 哥斯达黎加
古巴 = "CU"  # 古巴
佛得角 = "CV"  # 佛得角
库拉索 = "CW"  # 库拉索
圣诞岛 = "CX"  # 圣诞岛
塞浦路斯 = "CY"  # 塞浦路斯
捷克 = "CZ"  # 捷克
德国 = "DE"  # 德国
吉布提 = "DJ"  # 吉布提
丹麦 = "DK"  # 丹麦
多米尼克 = "DM"  # 多米尼克
多米尼加共和国 = "DO"  # 多米尼加共和国
阿尔及利亚 = "DZ"  # 阿尔及利亚
厄瓜多尔 = "EC"  # 厄瓜多尔
爱沙尼亚 = "EE"  # 爱沙尼亚
埃及 = "EG"  # 埃及
西撒哈拉 = "EH"  # 西撒哈拉
厄立特里亚 = "ER"  # 厄立特里亚
西班牙 = "ES"  # 西班牙
埃塞俄比亚 = "ET"  # 埃塞俄比亚
芬兰 = "FI"  # 芬兰
斐济 = "FJ"  # 斐济
福克兰群岛 = "FK"  # 福克兰群岛
密克罗尼西亚 = "FM"  # 密克罗尼西亚
法罗群岛 = "FO"  # 法罗群岛
法国 = "FR"  # 法国
加蓬 = "GA"  # 加蓬
英国 = "GB"  # 英国
格林纳达 = "GD"  # 格林纳达
格鲁吉亚 = "GE"  # 格鲁吉亚
法属圭亚那 = "GF"  # 法属圭亚那
格恩西岛 = "GG"  # 格恩西岛
加纳 = "GH"  # 加纳
直布罗陀 = "GI"  # 直布罗陀
格陵兰 = "GL"  # 格陵兰
冈比亚 = "GM"  # 冈比亚
几内亚 = "GN"  # 几内亚
瓜德罗普 = "GP"  # 瓜德罗普
赤道几内亚 = "GQ"  # 赤道几内亚
希腊 = "GR"  # 希腊
南乔治亚和南桑威奇群岛 = "GS"  # 南乔治亚和南桑威奇群岛
危地马拉 = "GT"  # 危地马拉
关岛 = "GU"  # 关岛
几内亚比绍 = "GW"  # 几内亚比绍
圭亚那 = "GY"  # 圭亚那
香港 = "HK"  # 香港
赫德岛和麦克唐纳群岛 = "HM"  # 赫德岛和麦克唐纳群岛
洪都拉斯 = "HN"  # 洪都拉斯
克罗地亚 = "HR"  # 克罗地亚
海地 = "HT"  # 海地
匈牙利 = "HU"  # 匈牙利
印度尼西亚 = "ID"  # 印度尼西亚
爱尔兰 = "IE"  # 爱尔兰
以色列 = "IL"  # 以色列
马恩岛 = "IM"  # 马恩岛
印度 = "IN"  # 印度
英属印度洋领地 = "IO"  # 英属印度洋领地
伊拉克 = "IQ"  # 伊拉克
伊朗 = "IR"  # 伊朗
冰岛 = "IS"  # 冰岛
意大利 = "IT"  # 意大利
泽西岛 = "JE"  # 泽西岛
牙买加 = "JM"  # 牙买加
约旦 = "JO"  # 约旦
日本 = "JP"  # 日本
肯尼亚 = "KE"  # 肯尼亚
吉尔吉斯斯坦 = "KG"  # 吉尔吉斯斯坦
柬埔寨 = "KH"  # 柬埔寨
基里巴斯 = "KI"  # 基里巴斯
科摩罗 = "KM"  # 科摩罗
圣基茨和尼维斯 = "KN"  # 圣基茨和尼维斯
朝鲜 = "KP"  # 朝鲜
韩国 = "KR"  # 韩国
科威特 = "KW"  # 科威特
开曼群岛 = "KY"  # 开曼群岛
哈萨克斯坦 = "KZ"  # 哈萨克斯坦
老挝 = "LA"  # 老挝
黎巴嫩 = "LB"  # 黎巴嫩
圣卢西亚 = "LC"  # 圣卢西亚
列支敦士登 = "LI"  # 列支敦士登
斯里兰卡 = "LK"  # 斯里兰卡
利比里亚 = "LR"  # 利比里亚
莱索托 = "LS"  # 莱索托
立陶宛 = "LT"  # 立陶宛
卢森堡 = "LU"  # 卢森堡
拉脱维亚 = "LV"  # 拉脱维亚
利比亚 = "LY"  # 利比亚
摩洛哥 = "MA"  # 摩洛哥
摩纳哥 = "MC"  # 摩纳哥
摩尔多瓦 = "MD"  # 摩尔多瓦
黑山 = "ME"  # 黑山
法属圣马丁 = "MF"  # 法属圣马丁
马达加斯加 = "MG"  # 马达加斯加
马绍尔群岛 = "MH"  # 马绍尔群岛
北马其顿 = "MK"  # 北马其顿
马里 = "ML"  # 马里
缅甸 = "MM"  # 缅甸
蒙古 = "MN"  # 蒙古
澳门 = "MO"  # 澳门
北马里亚纳群岛 = "MP"  # 北马里亚纳群岛
马提尼克 = "MQ"  # 马提尼克
毛里塔尼亚 = "MR"  # 毛里塔尼亚
蒙特塞拉特 = "MS"  # 蒙特塞拉特
马耳他 = "MT"  # 马耳他
毛里求斯 = "MU"  # 毛里求斯
马尔代夫 = "MV"  # 马尔代夫
马拉维 = "MW"  # 马拉维
墨西哥 = "MX"  # 墨西哥
马来西亚 = "MY"  # 马来西亚
莫桑比克 = "MZ"  # 莫桑比克
纳米比亚 = "NA"  # 纳米比亚
新喀里多尼亚 = "NC"  # 新喀里多尼亚
尼日尔 = "NE"  # 尼日尔
诺福克岛 = "NF"  # 诺福克岛
尼日利亚 = "NG"  # 尼日利亚
尼加拉瓜 = "NI"  # 尼加拉瓜
荷兰 = "NL"  # 荷兰
挪威 = "NO"  # 挪威
尼泊尔 = "NP"  # 尼泊尔
瑙鲁 = "NR"  # 瑙鲁
纽埃 = "NU"  # 纽埃
新西兰 = "NZ"  # 新西兰
阿曼 = "OM"  # 阿曼
巴拿马 = "PA"  # 巴拿马
秘鲁 = "PE"  # 秘鲁
法属玻里尼西亚 = "PF"  # 法属玻里尼西亚
巴布亚新几内亚 = "PG"  # 巴布亚新几内亚
菲律宾 = "PH"  # 菲律宾
巴基斯坦 = "PK"  # 巴基斯坦
波兰 = "PL"  # 波兰
圣皮埃尔和密克隆群岛 = "PM"  # 圣皮埃尔和密克隆群岛
皮特凯恩群岛 = "PN"  # 皮特凯恩群岛
波多黎各 = "PR"  # 波多黎各
巴勒斯坦 = "PS"  # 巴勒斯坦
葡萄牙 = "PT"  # 葡萄牙
帕劳 = "PW"  # 帕劳
巴拉圭 = "PY"  # 巴拉圭
卡塔尔 = "QA"  # 卡塔尔
留尼汪 = "RE"  # 留尼汪
罗马尼亚 = "RO"  # 罗马尼亚
塞尔维亚 = "RS"  # 塞尔维亚
俄罗斯 = "RU"  # 俄罗斯
卢旺达 = "RW"  # 卢旺达
沙特阿拉伯 = "SA"  # 沙特阿拉伯
所罗门群岛 = "SB"  # 所罗门群岛
塞舌尔 = "SC"  # 塞舌尔
苏丹 = "SD"  # 苏丹
瑞典 = "SE"  # 瑞典
新加坡 = "SG"  # 新加坡
斯洛文尼亚 = "SI"  # 斯洛文尼亚
斯瓦尔巴和扬马延 = "SJ"  # 斯瓦尔巴和扬马延
斯洛伐克 = "SK"  # 斯洛伐克
塞拉利昂 = "SL"  # 塞拉利昂
圣马力诺 = "SM"  # 圣马力诺
塞内加尔 = "SN"  # 塞内加尔
索马里 = "SO"  # 索马里
苏里南 = "SR"  # 苏里南
南苏丹 = "SS"  # 南苏丹
圣多美和普林西比 = "ST"  # 圣多美和普林西比
萨尔瓦多 = "SV"  # 萨尔瓦多
圣马丁 = "SX"  # 圣马丁
叙利亚 = "SY"  # 叙利亚
斯威士兰 = "SZ"  # 斯威士兰
特克斯和凯科斯群岛 = "TC"  # 特克斯和凯科斯群岛
乍得 = "TD"  # 乍得
法属南部领地 = "TF"  # 法属南部领地
多哥 = "TG"  # 多哥
泰国 = "TH"  # 泰国
塔吉克斯坦 = "TJ"  # 塔吉克斯坦
托克劳 = "TK"  # 托克劳
东帝汶 = "TL"  # 东帝汶
土库曼斯坦 = "TM"  # 土库曼斯坦
突尼斯 = "TN"  # 突尼斯
汤加 = "TO"  # 汤加
土耳其 = "TR"  # 土耳其
特立尼达和多巴哥 = "TT"  # 特立尼达和多巴哥
图瓦卢 = "TV"  # 图瓦卢
台湾 = "TW"  # 台湾
坦桑尼亚 = "TZ"  # 坦桑尼亚
乌克兰 = "UA"  # 乌克兰
乌干达 = "UG"  # 乌干达
美国本土外小岛屿 = "UM"  # 美国本土外小岛屿
美国 = "US"  # 美国
乌拉圭 = "UY"  # 乌拉圭
乌兹别克斯坦 = "UZ"  # 乌兹别克斯坦
梵蒂冈 = "VA"  # 梵蒂冈
圣文森特和格林纳丁斯 = "VC"  # 圣文森特和格林纳丁斯
委内瑞拉 = "VE"  # 委内瑞拉
英属维尔京群岛 = "VG"  # 英属维尔京群岛
美属维尔京群岛 = "VI"  # 美属维尔京群岛
越南 = "VN"  # 越南
瓦努阿图 = "VU"  # 瓦努阿图
瓦利斯群岛和富图纳群岛 = "WF"  # 瓦利斯群岛和富图纳群岛
萨摩亚 = "WS"  # 萨摩亚
也门 = "YE"  # 也门
马约特 = "YT"  # 马约特
南非 = "ZA"  # 南非
赞比亚 = "ZM"  # 赞比亚
津巴布韦 = "ZW"  # 津巴布韦
